@@ -9,6 +9,7 @@ from vectorcode import cli_utils
 from vectorcode.cli_utils import (
     CliAction,
     Config,
+    PromptCategory,
     QueryInclude,
     cleanup_path,
     expand_envs_in_dict,
@@ -53,14 +54,6 @@ async def test_config_import_from():
         assert config.db_settings == {"db_setting1": "db_value1"}
 
 
-@pytest.mark.asyncio
-async def test_config_import_from_fallback_host_port():
-    conf = {"host": "test_host"}
-    assert (await Config.import_from(conf)).db_url == "http://test_host:8000"
-    conf = {"port": 114514}
-    assert (await Config.import_from(conf)).db_url == "http://127.0.0.1:114514"
-
-
 @pytest.mark.asyncio
 async def test_config_import_from_invalid_path():
     config_dict: Dict[str, Any] = {"db_path": "/path/does/not/exist"}
@@ -491,11 +484,11 @@ async def test_parse_cli_args_init():
 
 
 @pytest.mark.asyncio
-async def test_parse_cli_args_hooks():
-    with patch("sys.argv", ["vectorcode", "hooks", "-f"]):
+async def test_parse_cli_args_prompts():
+    with patch("sys.argv", ["vectorcode", "prompts", "ls"]):
         config = await parse_cli_args()
-        assert config.action == CliAction.hooks
-        assert config.force
+        assert config.action == CliAction.prompts
+        assert config.prompt_categories == [PromptCategory.ls]
 
 
 @pytest.mark.asyncio
